
# Class: Address




URI: [ks:Address](https://w3id.org/linkml/tests/kitchen_sink/Address)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Person]++-%20addresses%200..*>[Address&#124;street:string%20%3F;city:string%20%3F],[Person])](https://yuml.me/diagram/nofunky;dir:TB/class/[Person]++-%20addresses%200..*>[Address&#124;street:string%20%3F;city:string%20%3F],[Person])

## Referenced by Record

 *  **None** *[addresses](addresses.md)*  <sub>0..\*</sub>  **[Address](Address.md)**

## Attributes


### Own

 * [street](street.md)  <sub>0..1</sub>
     * Range: [String](String.md)
 * [city](city.md)  <sub>0..1</sub>
     * Range: [String](String.md)
